/***************************************************************************
                          rtoolbar.h  -  description
                             -------------------
    begin                : Mon Sep 27 1999
    copyright            : (C) 1999 by Andreas Mustun
    email                : andrew@ribbonsoft.com
 ***************************************************************************/

/****************************************************************************
** rtoolbar.h 1998/09/04 A. Mustun RibbonSoft 
**
** Copyright (C) 1998 RibbonSoft.  All rights reserved.
**
*****************************************************************************/

#ifndef RTOOLBAR_H
#define RTOOLBAR_H

#include <qtoolbar.h>

#include "rprgdef.h"

/*! Toolbar (top)
*/
class RToolBar : public QToolBar
{
  Q_OBJECT
public:
  /*! Constructor
      \param _label The Label (not used)
      \param _parent The parent widget
      \param _dock Dock to Top, Left, ...
      \param _newLine Allow new Line
      \param _name Name
  */
  RToolBar(const QString& _label, QMainWindow* _parent,
           QMainWindow::ToolBarDock _dock= QMainWindow::Top, 
           bool _newLine = false,
           const char* _name=0);
  /*! Destructor
  */
  ~RToolBar();
    
protected:
  /*! Mouse release
  */
  void     mouseReleaseEvent(QMouseEvent* _ev);
  /*! Paint event
  */
  void     paintEvent(QPaintEvent*);

};



#endif

// EOF


